PoolCltAcceptor

Struct PoolCltAcceptor 

pub struct PoolCltAcceptor<M: Messenger + 'static, C: CallbackRecvSend<M> + 'static, const MAX_MSG_SIZE: usize> { /* private fields */ }
Abstraction used to accept new connections bound to the address and transmit them via a channel to the respective CltSendersPool & CltRecversPool.

It is designed to be used in a thread which is different from the thread that will be using the CltSendersPool & CltRecversPool.

Example

use links_blocking::prelude::*;
use links_core::unittest::setup::framer::{CltTestMessenger, SvcTestMessenger, TEST_MSG_FRAME_SIZE};

let addr = "127.0.0.1:8080";
let acceptor = SvcAcceptor::<_,_, TEST_MSG_FRAME_SIZE>::new(
    ConId::svc(Some("doctest"), addr, None),
    std::net::TcpListener::bind(addr).unwrap(),
    DevNullCallback::<SvcTestMessenger>::default().into(),
);

let (tx_recver, rx_recver) = std::sync::mpsc::channel();
let (tx_sender, rx_sender) = std::sync::mpsc::channel();

let mut pool = PoolCltAcceptor::new(tx_recver, tx_sender, acceptor);

println!("pool: {}", pool);

pool.pool_accept().unwrap();

Implementations

Source

impl<M: Messenger, C: CallbackRecvSend<M>, const MAX_MSG_SIZE: usize> PoolCltAcceptor<M, C, MAX_MSG_SIZE>

pub fn new( tx_recver: Sender<CltRecver<M, C, MAX_MSG_SIZE>>, tx_sender: Sender<CltSender<M, C, MAX_MSG_SIZE>>, acceptor: SvcAcceptor<M, C, MAX_MSG_SIZE>, ) -> Self