FrameReader

Struct FrameReader 

pub struct FrameReader<F: Framer, const MAX_MSG_SIZE: usize> { /* private fields */ }
Represents an abstraction for reading exactly oen frame from the TcpStream. Each call to the Self::read_frame will issue a Read::read system call on the underlying TcpStream. which will capture any bytes read into internal accumulator implemented as a BytesMut. This internal buffer will be passed to the generic impl of Framer::get_frame where it is user’s responsibility to inspect the buffer and split off a single frame.

Generic Parameters

  • F - A type that implements the Framer trait. This is used to split off a single frame from the internal buffer.
  • MAX_MSG_SIZE - The maximum size of a single frame. This is used to pre-allocate the internal buffer. Set this number to the maximum size of a single frame for your protocol.

Implementations

Source

impl<F: Framer, const MAX_MSG_SIZE: usize> FrameReader<F, MAX_MSG_SIZE>

pub fn new(con_id: ConId, reader: TcpStream) -> FrameReader<F, MAX_MSG_SIZE>

Creates a new instance of FrameReader

Arguments
  • con_id - ConId a unique identifier for the connection and used for logging
  • reader - TcpStream the underlying stream that will be used for reading
pub fn read_frame(&mut self) -> Result<Option<Bytes>, Error>

Reads exactly one frame from the underlying TcpStream and returns it as a [Some(Bytes)] or None if the connection was closed.

Note

If the FrameWriter pair is dropped then this method will return a [Ok(None)].