pub struct CanonicalEntry<T>where
T: Debug,{
pub con_id: ConId,
pub instant: Instant,
pub time: SystemTime,
pub msg: Message<T>,
}Expand description
A structure that is used to capture not only information about the message but also the following attributes:
con_id- Connection detail information via ConIdinstant- The instant of time the message was received via Instanttime- The system time the message was received via SystemTimemsg- relative direction of the message beingsentorreceivedvia Message variants Message::Sent or Message::Recv
Fields
con_id: ConIdinstant: Instanttime: SystemTimemsg: Message<T>Implementations
Sourceimpl<T> CanonicalEntry<T>where
T: Debug,
impl<T> CanonicalEntry<T>where
T: Debug,
pub fn try_into_recv(self) -> T
pub fn try_into_sent(self) -> T