Timer

Struct Timer 

pub struct Timer { /* private fields */ }
Class that allows scheduling tasks to be executed at repeating interval.

Implementations

Source

impl Timer

pub fn new(name: &str) -> Timer

Create new Timer instance with given name. Name is used for logging purposes.

pub fn schedule<T>(&self, name: &str, repeat: Duration, task: T)
where T: FnMut() -> TimerTaskStatus + Send + 'static,

pub fn terminate(self)

Drops all scheduled tasks and stops the executor thread

pub fn clear(&self)

Drops all scheduled tasks and parks executor thread until new tasks are scheduled.